==> streams-runtime-0.9.20-sources.jar: stream/runtime/Container.java <==
/*
 *  streams library
 *
 *  Copyright (C) 2011-2014 by Christian Bockermann, Hendrik Blom
 * 
 *  streams is a library, API and runtime environment for processing high
 *  volume data streams. It is composed of three submodules "stream-api",
 *  "stream-core" and "stream-runtime".
 *
 *  The streams library (and its submodules) is free software: you can 
 *  redistribute it and/or modify it under the terms of the 
 *  GNU Affero General Public License as published by the Free Software 
 *  Foundation, either version 3 of the License, or (at your option) any 
 *  later version.
 *
 *  The stream.ai library (and its submodules) is distributed in the hope
 *  that it will be useful, but WITHOUT ANY WARRANTY; without even the implied 
 *  warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Affero General Public License for more details.
 *
 *  You should have received a copy of the GNU Affero General Public License
 *  along with this program.  If not, see http://www.gnu.org/licenses/.
 */
package stream.runtime;

import java.net.URL;
import java.util.Map;
import java.util.concurrent.Callable;

/**
 * @author hendrik
 * 
 */
public class Container implements Callable<Boolean> {

	private URL url;
	private Map<String, String> args;

	public Container(URL url) {
		this.url = url;
	}

	public Container(URL url, Map<String, String> args) {
		this(url);
		this.args = args;
	}

	@Override
	public Boolean call() throws Exception {
		try {
			if (this.args == null)
				stream.run.main(this.url);
			else
				stream.run.mainWithMap(this.url, this.args);

			return true;
		} catch (Exception e) {
			e.printStackTrace();
			return false;
		}
	}
}

==> streams-runtime-1.0.10-sources.jar: stream/runtime/Container.java <==
/*
 *  streams library
 *
 *  Copyright (C) 2011-2014 by Christian Bockermann, Hendrik Blom
 * 
 *  streams is a library, API and runtime environment for processing high
 *  volume data streams. It is composed of three submodules "stream-api",
 *  "stream-core" and "stream-runtime".
 *
 *  The streams library (and its submodules) is free software: you can 
 *  redistribute it and/or modify it under the terms of the 
 *  GNU Affero General Public License as published by the Free Software 
 *  Foundation, either version 3 of the License, or (at your option) any 
 *  later version.
 *
 *  The stream.ai library (and its submodules) is distributed in the hope
 *  that it will be useful, but WITHOUT ANY WARRANTY; without even the implied 
 *  warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Affero General Public License for more details.
 *
 *  You should have received a copy of the GNU Affero General Public License
 *  along with this program.  If not, see http://www.gnu.org/licenses/.
 */
package stream.runtime;

import java.net.URL;
import java.util.Map;
import java.util.concurrent.Callable;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import stream.util.Variables;

/**
 * @author hendrik
 * 
 */
public class Container implements Callable<Boolean> {

	private URL url;
	private Map<String, String> args;
	static Logger log = LoggerFactory.getLogger(Container.class);
	private ProcessContainer container;

	public Container(URL url) {
		this.url = url;
	}

	public Container(URL url, Map<String, String> args) {
		this(url);
		this.args = args;
	}

	@Override
	public Boolean call() throws Exception {
		Variables props = StreamRuntime.loadUserProperties();
		if (props == null)
			props = new Variables();
		if (this.args != null)
			props.addVariables(args);

		log.debug("Creating process-container from configuration at {}", url);
		container = new ProcessContainer(url, null, props);

		log.info("Starting process-container...");
		container.run();
		log.info("Container started.");
		return true;
	}

	public void shutdown() {
		container.shutdown();
	}
}
